summaryrefslogtreecommitdiffstats
path: root/src/mesa/program/ir_to_mesa.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mesa/program/ir_to_mesa.cpp')
-rw-r--r--src/mesa/program/ir_to_mesa.cpp6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/mesa/program/ir_to_mesa.cpp b/src/mesa/program/ir_to_mesa.cpp
index 9fd10d1d91c..583cdef9f26 100644
--- a/src/mesa/program/ir_to_mesa.cpp
+++ b/src/mesa/program/ir_to_mesa.cpp
@@ -759,8 +759,10 @@ ir_to_mesa_visitor::visit(ir_variable *ir)
void
ir_to_mesa_visitor::visit(ir_loop *ir)
{
- /* Any bounded loops should have been lowered by lower_bounded_loops(). */
- assert(ir->counter == NULL);
+ /* Any normative loop bounds should have been lowered by
+ * lower_bounded_loops().
+ */
+ assert(ir->normative_bound < 0);
emit(NULL, OPCODE_BGNLOOP);